doapfiend.plugins.freshmeat.FreshmeatPlugin

Package doapfiend :: Package plugins :: Module freshmeat :: Class FreshmeatPlugin |
[hide private]
[frames] | no frames]

# Class FreshmeatPlugin

source code

     object --+
              |
    base.Plugin --+
                  |
                 FreshmeatPlugin

Get DOAP from Freshmeat package index

Instance Methods | [hide private]
__init__(self) Setup RDF/XML OutputPlugin class | source code
add_options(self, parser, output, search) Add plugin's options to doapfiend's opt parser | source code
unicode |
search(self, proxy=None) Get Freshmeat DOAP | source code
Inherited from `base.Plugin`: `configure`, `help` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
| name = ``'``freshmeat``'``
| prefix = ``'``fm``'``
| enabled = `False`
| enable_opt = ``'``freshmeat``'``

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self) (Constructor) | source code
Setup RDF/XML OutputPlugin class Overrides: object.__init__

### add_options(self, parser, output, search) | source code
Add plugin's options to doapfiend's opt parser Overrides: base.Plugin.add_options

### search(self, proxy=None) | source code
Get Freshmeat DOAP Parameters: `proxy` (string) - URL of optional HTTP proxy Returns: unicode Single DOAP